% Auto-generated chapter 25 for tirmidhi
% Hadiths in this chapter: 73

\hadithdefcmd{tirmidhi}{1788}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ يُونُسَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ مَا أَكَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي خِوَانٍ وَلاَ فِي سُكُرُّجَةٍ وَلاَ خُبِزَ لَهُ مُرَقَّقٌ ‏.‏ قَالَ فَقُلْتُ لِقَتَادَةَ فَعَلَى مَا كَانُوا يَأْكُلُونَ قَالَ عَلَى هَذِهِ السُّفَرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ قَالَ مُحَمَّدُ بْنُ بَشَّارٍ وَيُونُسُ هَذَا هُوَ يُونُسُ الإِسْكَافُ ‏.‏ وَقَدْ رَوَى عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ عَنْ قَتَادَةَ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{1788}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Yunus: From Qatadah, that Anas said: "The Messenger of Allah (ﷺ) never ate on a table, nor on small plates, not did he eat thin bread." He (Yunus) said: "I asked Qatadah: 'So what did he eat on ?' He said: 'On these leather dining sheets.'" [Abu 'Eisa said:] This Hadith is Hasan Gharib. Muhammad bin Bash-har said: "This Yunus is Yunus Al-Iskaf." And 'Abdul-Warith bin Sa'eed reported similarly from Sa'eed bin Abi 'Arubah, from Qatadah, from Anas [From the Prophet (ﷺ]}}
\hadithdefcmd{tirmidhi}{1789}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدِ بْنِ أَنَسٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ أَنْفَجْنَا أَرْنَبًا بِمَرِّ الظَّهْرَانِ فَسَعَى أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم خَلْفَهَا فَأَدْرَكْتُهَا فَأَخَذْتُهَا فَأَتَيْتُ بِهَا أَبَا طَلْحَةَ فَذَبَحَهَا بِمَرْوَةٍ فَبَعَثَ مَعِي بِفَخِذِهَا أَوْ بِوَرِكِهَا إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَكَلَهُ ‏.‏ قَالَ قُلْتُ أَكَلَهُ قَالَ قَبِلَهُ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ جَابِرٍ وَعَمَّارٍ وَمُحَمَّدِ بْنِ صَفْوَانَ وَيُقَالُ مُحَمَّدُ بْنُ صَيْفِيٍّ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ لاَ يَرَوْنَ بِأَكْلِ الأَرْنَبِ بَأْسًا ‏.‏ وَقَدْ كَرِهَ بَعْضُ أَهْلِ الْعِلْمِ أَكْلَ الأَرْنَبِ وَقَالُوا إِنَّهَا تَدْمِي ‏.‏\hadithno{1789}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Hisham b. Zaid: "I heard Anas saying: 'Once we provoked a rabbit at Marr Az-Zahran. So the Companions of the Messenger of Allah (ﷺ) rushed after it, and I caught up to it and captured it. I brought it to Abu Talhah who slaughtered it with Marwah. He sent me with its legs - or its thighs - to the Prophet (ﷺ) so he could eat it.'" He (Hisham) said: "I said: 'He ate it?' He said:'He accepted it.'" [Abu 'Eisa said:] There are narrations on this topic from Jubair, 'Ammar, Muhammad bin Safwan, and they say: Muhammad bin Saifi. This Hadith is Hasan Sahih. This is acted upon according to the people of knowledge. They saw no harm in eating rabbit. Some of the people of knowledge disliked eating rabbit, they said that it menstruates}}
\hadithdefcmd{tirmidhi}{1790}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ عَنْ أَكْلِ الضَّبِّ فَقَالَ ‏ "‏ لاَ آكُلُهُ وَلاَ أُحَرِّمُهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَأَبِي سَعِيدٍ وَابْنِ عَبَّاسٍ وَثَابِتِ بْنِ وَدِيعَةَ وَجَابِرٍ وَعَبْدِ الرَّحْمَنِ ابْنِ حَسَنَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي أَكْلِ الضَّبِّ فَرَخَّصَ فِيهِ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَكَرِهَهُ بَعْضُهُمْ ‏.‏ وَيُرْوَى عَنِ ابْنِ عَبَّاسٍ أَنَّهُ قَالَ أُكِلَ الضَّبُّ عَلَى مَائِدَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَإِنَّمَا تَرَكَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم تَقَذُّرًا ‏.‏\hadithno{1790}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Umar: "The Prophet (ﷺ) was asked about eating a mastigure and he said: 'I do not eat it, and I do not prohibit eating it.'" [He said:] There are narrations on this topic from 'Umar, Abu Sa'eed, Ibn 'Abbas, Thabit bin Wadi'ah, Jabir, and 'Abdur-Rahman bin Hasanah. [Abu 'Eisa said:] This Hadith is Hasan Sahih The People of knowledge have differed over eating mastigure. Some of the people of knowledge among the Companions of the Prophet (ﷺ) and others permitted it, while others considered it disliked. It has been related that Ibn 'Abbas said: "Mastigure was eaten on the dining spread of the Messenger of Allah (ﷺ), and the Messenger of Allah (ﷺ) only avoided it because it was distasteful to him}}
\hadithdefcmd{tirmidhi}{1791}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنِ ابْنِ أَبِي عَمَّارٍ، قَالَ قُلْتُ لِجَابِرٍ الضَّبُعُ صَيْدٌ هِيَ قَالَ نَعَمْ ‏.‏ قَالَ قُلْتُ آكُلُهَا قَالَ نَعَمْ ‏.‏ قَالَ قُلْتُ لَهُ أَقَالَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا وَلَمْ يَرَوْا بِأَكْلِ الضَّبُعِ بَأْسًا وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَرُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم حَدِيثٌ فِي كَرَاهِيَةِ أَكْلِ الضَّبُعِ وَلَيْسَ إِسْنَادُهُ بِالْقَوِيِّ وَقَدْ كَرِهَ بَعْضُ أَهْلِ الْعِلْمِ أَكْلَ الضَّبُعِ وَهُوَ قَوْلُ ابْنِ الْمُبَارَكِ ‏.‏ قَالَ يَحْيَى الْقَطَّانُ وَرَوَى جَرِيرُ بْنُ حَازِمٍ هَذَا الْحَدِيثَ عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ عَنِ ابْنِ أَبِي عَمَّارٍ عَنْ جَابِرٍ عَنْ عُمَرَ قَوْلَهُ ‏.‏ وَحَدِيثُ ابْنِ جُرَيْجٍ أَصَحُّ ‏.‏ وَابْنُ أَبِي عَمَّارٍ هُوَ عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي عَمَّارٍ الْمَكِّيُّ ‏.‏\hadithno{1791}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn Abi 'Ammar: "I asked Jabir: 'Is badger kind of game animal?' He said: 'Yes.'" He said: "I said: 'Should I eat it?' He said: 'Yes.'" He said: 'I said: 'Did the Messenger of Allah (ﷺ) say that ?' He said: 'Yes.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih. Some of the people of knowledge followed this. They did not see any harm eating badger. This is the view of Ahmad and Ishaq. A Hadith has been related from the Prophet (ﷺ) indicating disapproval of eating badger but its chain is not strong. Some of the people of knowledge disliked eating badger. This is the view of Ibn Al-Mubarak. Yahya bin Al-Qattan said: "Jarir bin Hazm reported this Hadith from 'Abdullah bin 'Ubaid bin 'Umair, from Ibn Abi 'Ammar, from Jabir, from 'Umar, as his saying. And the narration of Ibn Juraij (a narrator in the chain of this Hadith) is more correct. And Ibn Abi 'Ammar is 'Abdur-Rahman bin 'Abdullah bin Abi 'Ammar Al-Makki}}
\hadithdefcmd{tirmidhi}{1792}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ، عَنْ عَبْدِ الْكَرِيمِ بْنِ أَبِي الْمُخَارِقِ أَبِي أُمَيَّةَ، عَنْ حِبَّانَ بْنِ جَزْءٍ، عَنْ أَخِيهِ، خُزَيْمَةَ بْنِ جَزْءٍ قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ أَكْلِ الضَّبُعِ فَقَالَ ‏"‏ أَوَيَأْكُلُ الضَّبُعَ أَحَدٌ ‏"‏ ‏.‏ وَسَأَلْتُهُ عَنْ أَكْلِ الذِّئْبِ فَقَالَ ‏"‏ أَوَيَأْكُلُ الذِّئْبَ أَحَدٌ فِيهِ خَيْرٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِالْقَوِيِّ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ إِسْمَاعِيلَ بْنِ مُسْلِمٍ عَنْ عَبْدِ الْكَرِيمِ أَبِي أُمَيَّةَ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْحَدِيثِ فِي إِسْمَاعِيلَ وَعَبْدِ الْكَرِيمِ أَبِي أُمَيَّةَ وَهُوَ عَبْدُ الْكَرِيمِ بْنُ قَيْسِ بْنِ أَبِي الْمُخَارِقِ وَعَبْدُ الْكَرِيمِ بْنُ مَالِكٍ الْجَزَرِيُّ ثِقَةٌ ‏.‏\hadithno{1792}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Khuzaimah bin Jaz': "I asked the Messenger of Allah (ﷺ) about eating badger. He said: 'Does anyone eat badger?' So I asked him about eating wolf' He said: 'Does anyone who has any good in him eat wolf?'" [Abu 'Eisa said:] The chain for this Hadith is not strong. We do not know of it except as a narration of Isma'il bin Muslim from 'Abdul-Karim Abi Umayyah. Some of the people of Hadith have criticized Isma'il and 'Abdul Karim Abi Umayyah. And he is 'Abdul-Karim bin Qais, who is Ibn Abi Al-Mukhariq. While 'Abdul-Karim bin Malik Al-Jazari is trustworthy}}
\hadithdefcmd{tirmidhi}{1793}{حَدَّثَنَا قُتَيْبَةُ، وَنَصْرُ بْنُ عَلِيٍّ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرٍ، قَالَ أَطْعَمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم لُحُومَ الْخَيْلِ وَنَهَانَا عَنْ لُحُومِ الْحُمُرِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنْ عَمْرِو بْنِ دِينَارٍ عَنْ جَابِرٍ ‏.‏ وَرَوَاهُ حَمَّادُ بْنُ زَيْدٍ عَنْ عَمْرِو بْنِ دِينَارٍ عَنْ مُحَمَّدِ بْنِ عَلِيٍّ عَنْ جَابِرٍ وَرِوَايَةُ ابْنِ عُيَيْنَةَ أَصَحُّ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدًا يَقُولُ سُفْيَانُ بْنُ عُيَيْنَةَ أَحْفَظُ مِنْ حَمَّادِ بْنِ زَيْدٍ ‏.‏\hadithno{1793}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir: "The Messenger of Allah (ﷺ) allowed us to eat horse meat, and he forbade us from eating donkey meat." He said: There is something on this from Asma' bin Abi Bakr. Abu 'Eisa said: This Hadith is Hasan Sahih. This is how it was reported by more than one narrator, from 'Amr bin Dinar from Jabir. Hammad bin Zaid reported it from 'Amr bin Dinar from Muhammad bin 'Ali, from Jabir. The narration of Ibn 'Uyainah (no. 1793) is more correct. He said: I heard Muhammad saying: "Sufyan bin 'Uyainah is better at memorizing than Hammad bin Zaid}}
\hadithdefcmd{tirmidhi}{1794}{\hadithno{1794}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1795}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَرَّمَ يَوْمَ خَيْبَرَ كُلَّ ذِي نَابٍ مِنَ السِّبَاعِ وَالْمُجَثَّمَةَ وَالْحِمَارَ الإِنْسِيَّ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَجَابِرٍ وَالْبَرَاءِ وَابْنِ أَبِي أَوْفَى وَأَنَسٍ وَالْعِرْبَاضِ بْنِ سَارِيَةَ وَأَبِي ثَعْلَبَةَ وَابْنِ عُمَرَ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ وَغَيْرُهُ عَنْ مُحَمَّدِ بْنِ عَمْرٍو هَذَا الْحَدِيثَ وَإِنَّمَا ذَكَرُوا حَرْفًا وَاحِدًا نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ ‏.‏\hadithno{1795}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: "On the day of Khaibar, the Messenger of Allah (ﷺ) prohibited every predator possessing canines, and the Mujath-thamah, and the domestic donkey." He said: There are narrations on this topic from 'Ali, Jabir, Al-Bara', Ibn Abi Awfa, Anas, Al-'Irbad bin Sariyah, Abu Tha'labah, Ibn 'Umar and Abu Sa'eed. [Abu 'Eisa said:] This Hadith is Hasan Sahih. 'Abdul-'Aziz bin Muhammad and others reported this Hadith from Muhammad bin 'Amr, and they only mentioned one phrase: "The Messenger of Allah (ﷺ) prohibited every predator possessing canines}}
\hadithdefcmd{tirmidhi}{1796}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ الطَّائِيُّ، حَدَّثَنَا سَلْمُ بْنُ قُتَيْبَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي ثَعْلَبَةَ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ قُدُورِ الْمَجُوسِ فَقَالَ ‏ "‏ أَنْقُوهَا غَسْلاً وَاطْبُخُوا فِيهَا ‏"‏ ‏.‏ وَنَهَى عَنْ كُلِّ سَبُعٍ ذِي نَابٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ مَشْهُورٌ مِنْ حَدِيثِ أَبِي ثَعْلَبَةَ وَرُوِيَ عَنْهُ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏ وَأَبُو ثَعْلَبَةَ اسْمُهُ جُرْثُومٌ وَيُقَالُ جُرْهُمٌ وَيُقَالُ نَاشِبٌ ‏.‏ وَقَدْ ذُكِرَ هَذَا الْحَدِيثُ عَنْ أَبِي قِلاَبَةَ عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ عَنْ أَبِي ثَعْلَبَةَ ‏.‏\hadithno{1796}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Tha'labah Al-Khushani: "The Messenger of Allah (ﷺ) was asked about the pots of Zorastrians. He said: 'Clean them by washing them, and then cook in them." And he prohibited every predator possessing canines." This is a well known Hadith of Abu Tha'labah, and it has been reported from him through routes other than this. And Abu Tha'labah's name is Jurthum, and they say: Jurhum, and they say: Nashib. This Hadith has also been mentioned by Abu Qilabah from Abu 'Asma Ar-Rahbi, from Abu Tha'labah}}
\hadithdefcmd{tirmidhi}{1797}{حَدَّثَنَا عَلِيُّ بْنُ عِيسَى بْنِ يَزِيدَ الْبَغْدَادِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُحَمَّدٍ الْعَيْشِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَيُّوبَ، وَقَتَادَةَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ إِنَّا بِأَرْضِ أَهْلِ الْكِتَابِ فَنَطْبُخُ فِي قُدُورِهِمْ وَنَشْرَبُ فِي آنِيَتِهِمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ لَمْ تَجِدُوا غَيْرَهَا فَارْحَضُوهَا بِالْمَاءِ ‏"‏ ‏.‏ ثُمَّ قَالَ يَا رَسُولَ اللَّهِ إِنَّا بِأَرْضِ صَيْدٍ فَكَيْفَ نَصْنَعُ قَالَ ‏"‏ إِذَا أَرْسَلْتَ كَلْبَكَ الْمُكَلَّبَ وَذَكَرْتَ اسْمَ اللَّهِ فَقَتَلَ فَكُلْ وَإِنْ كَانَ غَيْرَ مُكَلَّبٍ فَذُكِّيَ فَكُلْ وَإِذَا رَمَيْتَ بِسَهْمِكَ وَذَكَرْتَ اسْمَ اللَّهِ فَقَتَلَ فَكُلْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1797}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Tha'labah Al-Khushani: That he said: "O Messenger of Allah! We live in a land of the People of Book and we cook in their containers, and drink in their vessels." The Messenger of Allah (ﷺ) said: "If you do not find other than them, then rinse them with water." The he said: "O Messenger of Allah! We live in a land of game, so what should we do ?" He said: "When you send your trained dog, and you mentioned the Name of Allah, and he kills it, then eat it. And when you shoot it with your bow, and it is killed, then eat it.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1798}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، وَأَبُو عَمَّارٍ قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، أَنَّ فَأْرَةً، وَقَعَتْ، فِي سَمْنٍ فَمَاتَتْ فَسُئِلَ عَنْهَا النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَلْقُوهَا وَمَا حَوْلَهَا وَكُلُوهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنِ الزُّهْرِيِّ عَنْ عُبَيْدِ اللَّهِ عَنِ ابْنِ عَبَّاسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ وَلَمْ يَذْكُرُوا فِيهِ عَنْ مَيْمُونَةَ وَحَدِيثُ ابْنِ عَبَّاسٍ عَنْ مَيْمُونَةَ أَصَحُّ ‏.‏ وَرَوَى مَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَهُوَ حَدِيثٌ غَيْرُ مَحْفُوظٍ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ وَحَدِيثُ مَعْمَرٍ عَنِ الزُّهْرِيِّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَذَكَرَ فِيهِ أَنَّهُ سُئِلَ عَنْهُ فَقَالَ ‏"‏ إِذَا كَانَ جَامِدًا فَأَلْقُوهَا وَمَا حَوْلَهَا وَإِنْ كَانَ مَائِعًا فَلاَ تَقْرَبُوهُ ‏"‏ ‏.‏ فَقَالَ هَذَا خَطَأٌ أَخْطَأَ فِيهِ مَعْمَرٌ ‏.‏ قَالَ وَالصَّحِيحُ حَدِيثُ الزُّهْرِيِّ عَنْ عُبَيْدِ اللَّهِ عَنِ ابْنِ عَبَّاسٍ عَنْ مَيْمُونَةَ ‏.‏\hadithno{1798}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Ibn 'Abbas: From Maimunah that a mouse fell in some cooking fat and died. So the Prophet (ﷺ) was asked about that and he said: "Remove it (the mouse) and what was around it and then eat it (the fat)." He said: There are something on this topic from Abu Hurairah. [Abu 'Eisa said:] This Hadith is Hasan Sahih. This Hadith has been related from Az-Zuhri, from 'Ubaidullah, from Ibn 'Abbas, saying: "The Prophet (ﷺ) as asked" and they did not mention Maimunah in it. The narration of Ibn 'Abbas from Maimunah is more correct. Ma'mar reported similar from Az-Zuhri, from Sa'eed bin Al-Musayyab, from Abu Hurairah, from the Prophet (ﷺ). But this hadith is not preserved. He said: I heard Muhammad bin Isma'il saying: "The Hadith of Ma'mar from Az-Zuhri, from Sa'eed bin al-Musayyab, from Abu Hurairah, from the Prophet (ﷺ)" - and he mentioned in it: 'That he was asked about it, so he said: "When it (the coking fat) is solid then remove it (the mouse) and what was around it. And when it is liquid then do not use it.'" This is a mistake. Ma'mar made a mistake with it. And he said: What is correct is the narration of Az-Zuhri from 'Ubaidullah, from Ibn 'Abbas, and Maimunah}}
\hadithdefcmd{tirmidhi}{1799}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَأْكُلْ أَحَدُكُمْ بِشِمَالِهِ وَلاَ يَشْرَبْ بِشِمَالِهِ فَإِنَّ الشَّيْطَانَ يَأْكُلُ بِشِمَالِهِ وَيَشْرَبُ بِشِمَالِهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَعُمَرَ بْنِ أَبِي سَلَمَةَ وَسَلَمَةَ بْنِ الأَكْوَعِ وَأَنَسِ بْنِ مَالِكٍ وَحَفْصَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا رَوَى مَالِكٌ وَابْنُ عُيَيْنَةَ عَنِ الزُّهْرِيِّ عَنْ أَبِي بَكْرِ بْنِ عُبَيْدِ اللَّهِ عَنِ ابْنِ عُمَرَ ‏.‏ وَرَوَى مَعْمَرٌ وَعُقَيْلٌ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ عَنِ ابْنِ عُمَرَ وَرِوَايَةُ مَالِكٍ وَابْنِ عُيَيْنَةَ أَصَحُّ ‏.‏\hadithno{1799}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated 'Abdullah bin 'Umar: That the Prophet (ﷺ) said: "Let none of you wat with his left hand nor drink with his left hand, for indeed Ash-Shaitan eats with his left hand and drinks with his left hand." He said: There are narrations on this topic from Jabir, 'Umar bin Abi Salamah, Salamah bin Al-Akwa', Anas bin Malik, and Hafsah. [Abu 'Eisa said:] This Hadith is Hasan Sahih. This is how Malik and Ibn 'Uyainah reported it from Az-Zuhri, from Abu Bakr bin 'Ubaidullah, from Ibn 'Umar. Ma'mar and 'Uqail reported it from Az-Zuhri, from Salim, from Ibn 'Umar. And the narration of Malik and Ibn 'Uyainah is more correct}}
\hadithdefcmd{tirmidhi}{1800}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَكَلَ أَحَدُكُمْ فَلْيَأْكُلْ بِيَمِينِهِ وَلْيَشْرَبْ بِيَمِينِهِ فَإِنَّ الشَّيْطَانَ يَأْكُلُ بِشِمَالِهِ وَيَشْرَبُ بِشِمَالِهِ ‏"‏ ‏.‏\hadithno{1800}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{Narrated Az-Zuhri:From Salim, from his father, that the Messenger of Allah (ﷺ) said: "When one of you eats, then let him eat with his right hand, and let him drink with his right hand, for indeed Ash-Shaitan eats with his left hand, and he drinks with his left hand}}
\hadithdefcmd{tirmidhi}{1801}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَكَلَ أَحَدُكُمْ فَلْيَلْعَقْ أَصَابِعَهُ فَإِنَّهُ لاَ يَدْرِي فِي أَيَّتِهِنَّ الْبَرَكَةُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏ وَكَعْبِ بْنِ مَالِكٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ سُهَيْلٍ ‏.‏ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَقَالَ هَذَا حَدِيثُ عَبْدِ الْعَزِيزِ مِنَ الْمُخْتَلِفِ لاَ يُعْرَفُ إِلاَّ مِنْ حَدِيثِهِ ‏.‏\hadithno{1801}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah: That Messenger of Allah (ﷺ) said: "When one of you eats, then let him lick his fingers, for indeed he does not know in which of them is the blessing." He said: There are narrations on this topic from Jabir, Ka'b bin Malik, and Anas. [Abu 'Eisa said:] This Hadith is Hasan Gharib, we do not know of it except from this route, as a narration of Suhail. I asked Muhammad about this Hadith, so he said: "This is among the diverse narrations of 'Abdul-'Aziz, we do not know of it except from his narration}}
\hadithdefcmd{tirmidhi}{1802}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَكَلَ أَحَدُكُمْ طَعَامًا فَسَقَطَتْ لُقْمَةٌ فَلْيُمِطْ مَا رَابَهُ مِنْهَا ثُمَّ لْيَطْعَمْهَا وَلاَ يَدَعْهَا لِلشَّيْطَانِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏\hadithno{1802}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir: That the Prophet (ﷺ) said: "When one of you eats food, and he drops a pieces of it, then let him remove anything suspicious from it and eat it. Do not leave it for Ash-Shaitan." He said: There is something about this from Anas}}
\hadithdefcmd{tirmidhi}{1803}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا مَا أَكَلَ طَعَامًا لَعِقَ أَصَابِعَهُ الثَّلاَثَ وَقَالَ ‏"‏ إِذَا مَا وَقَعَتْ لُقْمَةُ أَحَدِكُمْ فَلْيُمِطْ عَنْهَا الأَذَى وَلْيَأْكُلْهَا وَلاَ يَدَعْهَا لِلشَّيْطَانِ ‏"‏ ‏.‏ وَأَمَرَنَا أَنْ نَسْلُتَ الصَّحْفَةَ وَقَالَ ‏"‏ إِنَّكُمْ لاَ تَدْرُونَ فِي أَىِّ طَعَامِكُمُ الْبَرَكَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1803}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Anas: "When the Prophet (ﷺ) ate, he would lick his three fingers, and he said: 'If one of you drops a piece (of food) then let him remove any harm (dirt) from it and eat it, and do not leave it for Ash-Shaitan.' And he would order us to finish (clean) the dish. And he said: 'Indeed you do not know in which part of your food is the blessing.' [Abu 'Eisa said:] This Hadith is Hasan Gharib Sahih}}
\hadithdefcmd{tirmidhi}{1804}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ الْمُعَلَّى بْنُ رَاشِدٍ، قَالَ حَدَّثَتْنِي جَدَّتِي أُمُّ عَاصِمٍ، وَكَانَتْ أُمَّ وَلَدٍ، لِسِنَانِ بْنِ سَلَمَةَ قَالَتْ دَخَلَ عَلَيْنَا نُبَيْشَةُ الْخَيْرِ وَنَحْنُ نَأْكُلُ فِي قَصْعَةٍ فَحَدَّثَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَكَلَ فِي قَصْعَةٍ ثُمَّ لَحِسَهَا اسْتَغْفَرَتْ لَهُ الْقَصْعَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الْمُعَلَّى بْنِ رَاشِدٍ ‏.‏ وَقَدْ رَوَى يَزِيدُ بْنُ هَارُونَ وَغَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ عَنِ الْمُعَلَّى بْنِ رَاشِدٍ هَذَا الْحَدِيثَ ‏.‏\hadithno{1804}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Mu'alla bin Rashid: "My grandmother, Umm 'Asim narrated to me - and she was the slave woman of Sinan bin Salamah - she said: 'Nubaishah Al-Khair entered upon us while we were eating from a large bowl. He narrated to us that the Messenger of Allah (ﷺ) said: "Whoever eats from A Qas'ah, then licks it, the Qas'ah will seek forgiveness for him." [Abu 'Eisa said:] This Hadith is Gharib, we do not know of it except through the narration of Al-Mu'alla bin Rashid. And Yazid bin Harun and others among the A'immah reported this Hadith from Al-Mu'alla bin Rashid}}
\hadithdefcmd{tirmidhi}{1805}{حَدَّثَنَا قُتَيْبَةُ أَبُو رَجَاءٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْبَرَكَةَ تَنْزِلُ وَسَطَ الطَّعَامِ فَكُلُوا مِنْ حَافَتَيْهِ وَلاَ تَأْكُلُوا مِنْ وَسَطِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ إِنَّمَا يُعْرَفُ مِنْ حَدِيثِ عَطَاءِ بْنِ السَّائِبِ ‏.‏ وَقَدْ رَوَاهُ شُعْبَةُ وَالثَّوْرِيُّ عَنْ عَطَاءِ بْنِ السَّائِبِ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{1805}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas: That the Prophet (ﷺ) said: "Indeed the blessing descends to the middle of the food, so eat from its edges, and do not eat from its middle." [Abu 'Eisa said:] This Hadith is Hasan Sahih. It is only known through the narration of 'Ata' bin As-Sa'ib. Shu'bah and Ath-Thawri reported from 'Ata' bin As-Sa'ib. There is something about this topic from Ibn 'Umar}}
\hadithdefcmd{tirmidhi}{1806}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنَا عَطَاءٌ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ - قَالَ أَوَّلَ مَرَّةٍ الثُّومِ ثُمَّ قَالَ الثُّومِ وَالْبَصَلِ وَالْكُرَّاثِ فَلاَ يَقْرَبْنَا فِي مَسَاجِدِنَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَأَبِي أَيُّوبَ وَأَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ وَجَابِرِ بْنِ سَمُرَةَ وَقُرَّةَ بْنِ إِيَاسٍ الْمُزَنِيِّ وَابْنِ عُمَرَ ‏.‏\hadithno{1806}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir: That the Messenger of Allah (ﷺ) said: "Whoever eats from these - the first time, he said garlic, then he said - garlic, onion, and leek, then let him not approach our Masjid." [Abu 'Eisa said:] This Hadith is Hasan Sahih. He said: There are narrations on this topic from 'Umar, Abu Ayyub, Abu Hurairah, Abu Sa'eed, Jabir bin Samurah, Qurrah [bin Iyas Al-Muzani] and Ibn 'Umar}}
\hadithdefcmd{tirmidhi}{1807}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَنْبَأَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، سَمِعَ جَابِرَ بْنَ سَمُرَةَ، يَقُولُ نَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى أَبِي أَيُّوبَ وَكَانَ إِذَا أَكَلَ طَعَامًا بَعَثَ إِلَيْهِ بِفَضْلِهِ فَبَعَثَ إِلَيْهِ يَوْمًا بِطَعَامٍ وَلَمْ يَأْكُلْ مِنْهُ النَّبِيُّ صلى الله عليه وسلم فَلَمَّا أَتَى أَبُو أَيُّوبَ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ ‏"‏ فِيهِ ثُومٌ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ أَحَرَامٌ هُوَ قَالَ ‏"‏ لاَ وَلَكِنِّي أَكْرَهُهُ مِنْ أَجْلِ رِيحِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1807}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir bin Samurah: "The Messenger of Allah (ﷺ) was staying with Abu Ayyub. When he ate some food, he would send what was left to him. So one day he sent him some food but the Prophet (ﷺ) did not eat from it. So Abu Ayyub went to the Prophet (ﷺ) and mentioned that to him. The Prophet (ﷺ) said: 'It contained garlic.' So he said: 'O Messenger of Allah! Is it unlawful?' He said: 'No, I dislike it because of its odor.'" He said: This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1808}{حَدَّثَنَا مُحَمَّدُ بْنُ مَدُّويَهْ، حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْجَرَّاحُ بْنُ مَلِيحٍ، وَالِدُ، وَكِيعٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ شَرِيكِ بْنِ حَنْبَلٍ، عَنْ عَلِيٍّ، أَنَّهُ قَالَ نُهِيَ عَنْ أَكْلِ الثُّومِ، إِلاَّ مَطْبُوخًا ‏.‏\hadithno{1808}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sharik bin Hanbal:That 'Ali said: "Eating garlic was prohibited except when cooked}}
\hadithdefcmd{tirmidhi}{1809}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، عَنْ شَرِيكِ بْنِ حَنْبَلٍ، عَنْ عَلِيٍّ، قَالَ لاَ يَصْلُحُ أَكْلُ الثُّومِ إِلاَّ مَطْبُوخًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا الْحَدِيثُ لَيْسَ إِسْنَادُهُ بِذَلِكَ الْقَوِيِّ وَقَدْ رُوِيَ هَذَا عَنْ عَلِيٍّ قَوْلَهُ وَرُوِيَ عَنْ شَرِيكِ بْنِ حَنْبَلٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ قَالَ مُحَمَّدٌ الْجَرَّاحُ بْنُ مَلِيحٍ صَدُوقٌ وَالْجَرَّاحُ بْنُ الضَّحَّاكِ مُقَارِبُ الْحَدِيثِ ‏.‏\hadithno{1809}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sharik bin Hanbal:That 'Ali said: "Eating garlic is no good, except when cooked." [Abu 'Eisa said:] This chain of this Hadith is not strong. It has been reported as a saying of 'Ali and it has been reported from Sharik bin Hanbal from the Prophet (ﷺ) in Mursal form. Muhammad said: "Al-Jarrah bin Malih (one of the narratos) is truthful, and Al-Jarrah bin Ad-Dahhak is Muqarib (average) in Hadith}}
\hadithdefcmd{tirmidhi}{1810}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ الْبَزَّارُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنْ أَبِيهِ، أَنَّ أُمَّ أَيُّوبَ، أَخْبَرَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَزَلَ عَلَيْهِمْ فَتَكَلَّفُوا لَهُ طَعَامًا فِيهِ مِنْ بَعْضِ هَذِهِ الْبُقُولِ فَكَرِهَ أَكْلَهُ فَقَالَ لأَصْحَابِهِ ‏ "‏ كُلُوهُ فَإِنِّي لَسْتُ كَأَحَدِكُمْ إِنِّي أَخَافُ أَنْ أُوذِيَ صَاحِبِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَأُمُّ أَيُّوبَ هِيَ امْرَأَةُ أَبِي أَيُّوبَ الأَنْصَارِيِّ ‏.‏\hadithno{1810}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Ubaidullah bin Abi Burdah: From his father that Umm Ayyub informed him that the Prophet (ﷺ) had stayed with them, and they prepared some food for him containing some of these vegetables. But he disliked eating it, so he said to his Companions: "Eat it, for I am not like you are, I fear that I will offend my companion." [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib. Umm Ayyub is the wife of Abu Ayyub Al-Ansari}}
\hadithdefcmd{tirmidhi}{1811}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ أَبِي خَلْدَةَ، عَنْ أَبِي الْعَالِيَةِ، قَالَ الثُّومُ مِنْ طَيِّبَاتِ الرِّزْقِ ‏.‏ وَأَبُو خَلْدَةَ اسْمُهُ خَالِدُ بْنُ دِينَارٍ وَهُوَ ثِقَةٌ عِنْدَ أَهْلِ الْحَدِيثِ وَقَدْ أَدْرَكَ أَنَسَ بْنَ مَالِكٍ وَسَمِعَ مِنْهُ وَأَبُو الْعَالِيَةِ اسْمُهُ رُفَيْعٌ هُوَ الرِّيَاحِيُّ قَالَ عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ كَانَ أَبُو خَلْدَةَ خِيَارًا مُسْلِمًا ‏.‏\hadithno{1811}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad Maqtu; Al-Albani: Daif Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Khaldah:That Abu Al-'Aliyah said: "garlic is among the good provisions." Abu Khaldah's name is Khalid bin Dinar, and he is trustworthy according to the people of Hadith. He saw Anas bin Malik and heard narrations from him. Abu Al-'Aliyah's name is Rufai' and he is Ar-Riyahi. 'Abdur-Rahman bin Mahdi said: "Abu Khaldah was preferable, reliable}}
\hadithdefcmd{tirmidhi}{1812}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَغْلِقُوا الْبَابَ وَأَوْكِئُوا السِّقَاءَ وَأَكْفِئُوا الإِنَاءَ أَوْ خَمِّرُوا الإِنَاءَ وَأَطْفِئُوا الْمِصْبَاحَ فَإِنَّ الشَّيْطَانَ لاَ يَفْتَحُ غُلُقًا وَلاَ يَحِلُّ وِكَاءً وَلاَ يَكْشِفُ آنِيَةً وَإِنَّ الْفُوَيْسِقَةَ تُضْرِمُ عَلَى النَّاسِ بَيْتَهُمْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ جَابِرٍ ‏.‏\hadithno{1812}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir: That the Prophet (ﷺ) said: "Close the door, tie the water-skin, turn over the vessel, or cover the vessel, and extinguish the torch. Indeed Ash-Shaitan does not open what is closed, nor undo what is fastened, nor uncover a vessel, but the small vermin may cause a fire in people's houses." He said: There are narrations on this topic from Ibn 'Umar, Abu Hurairah, and Ibn 'Abbas. [Abu 'Eisa said:] This Hadith is Hasan Sahih, and it has been reported through other routes from Jabir}}
\hadithdefcmd{tirmidhi}{1813}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَتْرُكُوا النَّارَ فِي بُيُوتِكُمْ حِينَ تَنَامُونَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1813}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Salim: From his father, that the Messenger of Allah (ﷺ) said: "Do not leave the fire (burning) in your houses when you sleep." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1814}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، وَعُبَيْدُ اللَّهِ، عَنِ الثَّوْرِيِّ، عَنْ جَبَلَةَ بْنِ سُحَيْمٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَقْرِنَ بَيْنَ التَّمْرَتَيْنِ حَتَّى يَسْتَأْذِنَ صَاحِبَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَعْدٍ مَوْلَى أَبِي بَكْرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1814}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar: "The Messenger of Allah (ﷺ) prohibited taking two dates at a time until seeking permission from one's companion." He said: There is something on this topic from Sa'd the freed slave of Abu Bakr. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1815}{حَدَّثَنَا مُحَمَّدُ بْنُ سَهْلِ بْنِ عَسْكَرٍ الْبَغْدَادِيُّ، وَعَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْتٌ لاَ تَمْرَ فِيهِ جِيَاعٌ أَهْلُهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَلْمَى امْرَأَةِ أَبِي رَافِعٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ هِشَامِ بْنِ عُرْوَةَ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ قَالَ وَسَأَلْتُ الْبُخَارِيَّ عَنْ هَذَا الْحَدِيثِ فَقَالَ لاَ أَعْلَمُ أَحَدًا رَوَاهُ غَيْرَ يَحْيَى بْنِ حَسَّانَ ‏.‏\hadithno{1815}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Aishah: That the Prophet (ﷺ) said: "A house without dates, its inhabitants will be hungry." He said: There are narrations on this topic from Salma the wife of Abu Rafi'. [Abu 'Eisa said:] This Hadith is Hasan Gharib from this route. We do not know of it to be a narration of Hisham bin 'Urwah except through this route. He said: I asked Al-Bukhari about this Hadith and he said: "I do not know of anyone who reported it other than Yahya bin Hassan}}
\hadithdefcmd{tirmidhi}{1816}{حَدَّثَنَا هَنَّادٌ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ لَيَرْضَى عَنِ الْعَبْدِ أَنْ يَأْكُلَ الأَكْلَةَ أَوْ يَشْرَبَ الشَّرْبَةَ فَيَحْمَدَهُ عَلَيْهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُقْبَةَ بْنِ عَامِرٍ وَأَبِي سَعِيدٍ وَعَائِشَةَ وَأَبِي أَيُّوبَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَاهُ غَيْرُ وَاحِدٍ عَنْ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ نَحْوَهُ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ ‏.‏\hadithno{1816}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Anas bin Malik: That the Prophet (ﷺ) said: "Indeed Allah is pleased with the slave who, upon eating his food or drinking his drink, he praises Him for it." He said: There are narrations on this topic from 'Uqbah bin 'Amir, Abu Sa'eed, 'Aishah, Abu Ayyub, and Abu Hurairah. [Abu 'Eisa said:] This Hadith is Hasan. More than one narrator has reported it from Zakariyya bin Abi Za'idah similarly, and we do not know of it except through the narration of Zakariyya bin Abi Za'idah}}
\hadithdefcmd{tirmidhi}{1817}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الأَشْقَرُ، وَإِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالاَ حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا الْمُفَضَّلُ بْنُ فَضَالَةَ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَخَذَ بِيَدِ مَجْذُومٍ فَأَدْخَلَهُ مَعَهُ فِي الْقَصْعَةِ ثُمَّ قَالَ ‏ "‏ كُلْ بِسْمِ اللَّهِ ثِقَةً بِاللَّهِ وَتَوَكُّلاً عَلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ يُونُسَ بْنِ مُحَمَّدٍ عَنِ الْمُفَضَّلِ بْنِ فَضَالَةَ ‏.‏ وَالْمُفَضَّلُ بْنُ فَضَالَةَ هَذَا شَيْخٌ بَصْرِيٌّ وَالْمُفَضَّلُ بْنُ فَضَالَةَ شَيْخٌ آخَرُ مِصْرِيٌّ أَوْثَقُ مِنْ هَذَا وَأَشْهَرُ ‏.‏ وَقَدْ رَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ حَبِيبِ بْنِ الشَّهِيدِ عَنِ ابْنِ بُرَيْدَةَ أَنَّ ابْنَ عُمَرَ أَخَذَ بِيَدِ مَجْذُومٍ وَحَدِيثُ شُعْبَةَ أَثْبَتُ عِنْدِي وَأَصَحُّ ‏.‏\hadithno{1817}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir bin ‘Abdullah : "The Messenger of Allah (ﷺ) took the hand of a leper and put it in the Qas'ah. Then he said: 'Eat in Allah's Name, trusting in Allah and relying upon Him.'" [Abu 'Eisa said:] This is a Gharib Hadith, we do not know of it except through the report of Yunus bin Muhammad, from Al-Mufaddal bin Fadalah, a Shaikh from Al-Basrah. There is another Shaikh from Al-Basrah named Al-Mufaddal bin Fadalah, who is more reliable han this one and more popular. Shu'bah reported this Hadith from Habib bin Ash-Shahid, from Ibn Buraidah: "That Ibn 'Umar took the hand of a leper" and the narration of Shu'bah is more appropriate to me and more correct}}
\hadithdefcmd{tirmidhi}{1818}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْكَافِرُ يَأْكُلُ فِي سَبْعَةِ أَمْعَاءٍ وَالْمُؤْمِنُ يَأْكُلُ فِي مِعًى وَاحِدٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ وَأَبِي بَصْرَةَ الْغِفَارِيِّ وَأَبِي مُوسَى وَجَهْجَاهٍ الْغِفَارِيِّ وَمَيْمُونَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏\hadithno{1818}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Ibn 'Umar: That the Prophet (ﷺ) said: "The disbeliever eats with seven intestines and the believer eats with one intestine." [Abu 'Eisa said:] This Hadith is Hasan Sahih. He said: There are narrations on this topic from Abu Hurairah, Abu Sa'eed, Abu Basrah Al-Ghifari, Abu Musa, Jahjah Al-Ghifari, Maimunah, and 'Abdullah bin 'Amr}}
\hadithdefcmd{tirmidhi}{1819}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ضَافَهُ ضَيْفٌ كَافِرٌ فَأَمَرَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَاةٍ فَحُلِبَتْ فَشَرِبَ ثُمَّ أُخْرَى فَشَرِبَهُ ثُمَّ أُخْرَى فَشَرِبَهُ حَتَّى شَرِبَ حِلاَبَ سَبْعِ شِيَاهٍ ثُمَّ أَصْبَحَ مِنَ الْغَدِ فَأَسْلَمَ فَأَمَرَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَاةٍ فَحُلِبَتْ فَشَرِبَ حِلاَبَهَا ثُمَّ أَمَرَ لَهُ بِأُخْرَى فَلَمْ يَسْتَتِمَّهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُؤْمِنُ يَشْرَبُ فِي مِعًى وَاحِدٍ وَالْكَافِرُ يَشْرَبُ فِي سَبْعَةِ أَمْعَاءٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ سُهَيْلٍ ‏.‏\hadithno{1819}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah: "The Messenger of Allah (ﷺ) had a disbeliever as a guest. So the Messenger of Allah (ﷺ) ordered that a sheep be milked so he could drink. Then another was milked so he could drink, then another, so he drank until he had drank the milk of seven sheep. The he awoke the next morning and accepted Islam. The Messenger of Allah (ﷺ) ordered that a sheep be milked so he could drink its milk, then he ordered for another but he could not finish it. So the Messenger of Allah (ﷺ) said: 'The believer drinks with one intestine and the disbeliever drinks with seven.'" [Abu 'Eisa said:] This Hadith is Sahih Hasan Gharib as a narration of Suhail}}
\hadithdefcmd{tirmidhi}{1820}{\hadithno{1820}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1821}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي يَعْفُورٍ الْعَبْدِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، أَنَّهُ سُئِلَ عَنِ الْجَرَادِ، فَقَالَ غَزَوْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم سِتَّ غَزَوَاتٍ نَأْكُلُ الْجَرَادَ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَى سُفْيَانُ بْنُ عُيَيْنَةَ عَنْ أَبِي يَعْفُورٍ هَذَا الْحَدِيثَ وَقَالَ سِتَّ غَزَوَاتٍ وَرَوَى سُفْيَانُ الثَّوْرِيُّ وَغَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ أَبِي يَعْفُورٍ فَقَالَ سَبْعَ غَزَوَاتٍ ‏. قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو يَعْفُورٍ اسْمُهُ وَاقِدٌ وَيُقَالُ وَقْدَانُ أَيْضًا وَأَبُو يَعْفُورٍ الآخَرُ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ عُبَيْدِ بْنِ نِسْطَاسَ ‏.‏\hadithno{1821}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Ya'fur Al-'Abdi: That 'Abdullah bin Abi Awfa was asked about locust. He said: "I participated in six military expeditions with the Messenger of Allah (saws, (and) we ate locust." [Abu 'Eisa said:] This is how Sufyan bin 'Uyainah reported this Hadith from Abu Ya'fur. He said: "Six military expeditions," while Sufyan Ath-Thawri reported this Hadith from Abu Ya'fur, and he said: "Seven military expeditions." He said: There are narrations on this topic from Ibn 'Umar and Jabir. He said: This Hadith is Hasan Sahih. Abu Yu'fur's name is Waqid. They also call him Waqdan. There is another Abu Ya'fur whose name is 'Adbur-Rahman bin 'Ubaid bin Nistas}}
\hadithdefcmd{tirmidhi}{1822}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ، وَالْمُؤَمَّلُ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي يَعْفُورٍ، عَنِ ابْنِ أَبِي أَوْفَى، قَالَ غَزَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم سَبْعَ غَزَوَاتٍ نَأْكُلُ الْجَرَادَ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى شُعْبَةُ، هَذَا الْحَدِيثَ عَنْ أَبِي يَعْفُورٍ، عَنِ ابْنِ أَبِي أَوْفَى، قَالَ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم غَزَوَاتٍ نَأْكُلُ الْجَرَادَ ‏.‏ حَدَّثَنَا بِذَلِكَ مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ بِهَذَا ‏.‏\hadithno{1822}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Ya'fur: That Ibn Abi Awfa said: "We participated in seven military expeditions with the Messenger of Allah (ﷺ), (and) we ate locust." [Abu 'Eisa said:] Shu'bah reported this Hadith from Abu Ya'fur, from Ibn Awfa and said: "We participated in military expeditions with the Messenger of Allah (ﷺ) (and) we ate locust." This was narrated to us by Muhammad bin Bash-shar (who said): "Muhammad bin Ja'far narrated to us from Shu'bah}}
\hadithdefcmd{tirmidhi}{1823}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو النَّضْرِ، هَاشِمُ بْنُ الْقَاسِمِ قَالَ حَدَّثَنَا زِيَادُ بْنُ عَبْدِ اللَّهِ بْنِ عُلاَثَةَ، عَنْ مُوسَى بْنِ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، وَأَنَسِ بْنِ مَالِكٍ، قَالاَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا دَعَا عَلَى الْجَرَادِ قَالَ ‏"‏ اللَّهُمَّ أَهْلِكِ الْجَرَادَ اقْتُلْ كِبَارَهُ وَأَهْلِكْ صِغَارَهُ وَأَفْسِدْ بَيْضَهُ وَاقْطَعْ دَابِرَهُ وَخُذْ بِأَفْوَاهِهِمْ عَنْ مَعَاشِنَا وَأَرْزَاقِنَا إِنَّكَ سَمِيعُ الدُّعَاءِ ‏"‏ ‏.‏ قَالَ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ كَيْفَ تَدْعُو عَلَى جُنْدٍ مِنْ أَجْنَادِ اللَّهِ بِقَطْعِ دَابِرِهِ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهَا نَثْرَةُ حُوتٍ فِي الْبَحْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَمُوسَى بْنُ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيُّ قَدْ تُكُلِّمَ فِيهِ وَهُوَ كَثِيرُ الْغَرَائِبِ وَالْمَنَاكِيرِ وَأَبُوهُ مُحَمَّدُ بْنُ إِبْرَاهِيمَ ثِقَةٌ وَهُوَ مَدَنِيٌّ ‏.‏\hadithno{1823}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Narrated At-Taimi: From Jabir bin 'Abdullah and Anas bin Malik who said: "When the Messenger of Allah (ﷺ) supplicated against locusts he would say: 'O Allah! Destroy the locusts, kill the large among him, and destroy the small, spoil his core, and cut off his rear. Take their mouths from our livelihood and our sustenance. Verily, You indeed listen to the supplication!' So a man said: 'O Messenger of Allah! How is it that you supplicate against one of the Allah's armies that He cut off their rear?'" He said: "So the Messenger of Allah (ﷺ) said: 'They are bit scattered from a fish in the ocean.'" [Abu 'Eisa said:] This Hadith is Gharib. We do not know of it except from this route. And Musa bin Muhammad bin Ibrahim At-Taimi has been criticized. He narrates many Gharib and Munkar narrations. His father Muhammad bin Ibrahim is trustworthy, and he is from Al-Madinah}}
\hadithdefcmd{tirmidhi}{1824}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَكْلِ الْجَلاَّلَةِ وَأَلْبَانِهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَى الثَّوْرِيُّ عَنِ ابْنِ أَبِي نَجِيحٍ عَنْ مُجَاهِدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏\hadithno{1824}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Umar: "The Prophet (ﷺ) prohibited eating the Jallalah and milking it." He said: There is something on this topic from 'Abdullah bin 'Abbas. [Abu 'Eisa said:] This Hadith is Hasan Gharib. Ath-Thawri reported it from Ibn Abi Najih, from Mujahid, from the Prophet (ﷺ) in Mursal form}}
\hadithdefcmd{tirmidhi}{1825}{\hadithno{1825}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1826}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ الطَّائِيُّ، حَدَّثَنَا أَبُو قُتَيْبَةَ، عَنْ أَبِي الْعَوَّامِ، عَنْ قَتَادَةَ، عَنْ زَهْدَمٍ الْجَرْمِيِّ، قَالَ دَخَلْتُ عَلَى أَبِي مُوسَى وَهُوَ يَأْكُلُ دَجَاجًا فَقَالَ ادْنُ فَكُلْ فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْكُلُهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ زَهْدَمٍ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ زَهْدَمٍ ‏.‏ وَأَبُو الْعَوَّامِ هُوَ عِمْرَانُ الْقَطَّانُ ‏.‏\hadithno{1826}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Zahdam Al-Jarmi: "I entered upon Abu Musa while he was eating chicken, and he said: 'Sit and eat, for indeed I saw the Messenger of Allah (ﷺ) eating it.'" [Abu 'Eisa said:] This Hadith is Hasan. This Hadith has been reported through other routes from Zahdam, and we do not know of it except as the narration of Zahdam. (One of the narrators) Abu Al-'Awwam is 'Imran Al-Qattan}}
\hadithdefcmd{tirmidhi}{1827}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ زَهْدَمٍ، عَنْ أَبِي مُوسَى، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْكُلُ لَحْمَ دَجَاجٍ ‏.‏ قَالَ وَفِي الْحَدِيثِ كَلاَمٌ أَكْثَرُ مِنْ هَذَا ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى أَيُّوبُ السَّخْتِيَانِيُّ هَذَا الْحَدِيثَ أَيْضًا عَنِ الْقَاسِمِ التَّمِيمِيِّ وَعَنْ أَبِي قِلاَبَةَ عَنْ زَهْدَمٍ (الْجَرْمِيِّ) ‏.‏\hadithno{1827}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Zahdam: From Abu Musa who said: "I saw the Messenger of Allah (ﷺ) eating chicken meat." He said: The Hadith has more statements that this. And this Hadith is Hasan Sahih. Ayyub As-Sakhtiyani also reported this Hadith from Al-Qasim At-Tamimi, and, from Abu Qilabah, from Zahdam Al-Jarmi}}
\hadithdefcmd{tirmidhi}{1828}{حَدَّثَنَا الْفَضْلُ بْنُ سَهْلٍ الأَعْرَجُ الْبَغْدَادِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ مَهْدِيٍّ، عَنْ إِبْرَاهِيمَ بْنِ عُمَرَ بْنِ سَفِينَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ أَكَلْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَحْمَ حُبَارَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَإِبْرَاهِيمُ بْنُ عُمَرَ بْنِ سَفِينَةَ رَوَى عَنْهُ ابْنُ أَبِي فُدَيْكٍ وَيُقَالُ بُرَيْهُ بْنُ عُمَرَ بْنِ سَفِينَةَ ‏.‏\hadithno{1828}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibrahim bin 'Umar bin Safinah: From his father, from his grandfather that he said: "I ate bustard meat with the Messenger of Allah (ﷺ)." [Abu 'Eisa said:] This Hadith is Gharib, we do not know of it except from this route. Ibn Abi Fudaik reported from Ibrahim bin 'Umar bin Safinah and he has been called Buraih bin 'Umar bin Safinah}}
\hadithdefcmd{tirmidhi}{1829}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي مُحَمَّدُ بْنُ يُوسُفَ، أَنَّ عَطَاءَ بْنَ يَسَارٍ، أَخْبَرَهُ أَنَّ أُمَّ سَلَمَةَ أَخْبَرَتْهُ أَنَّهَا، قَرَّبَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم جَنْبًا مَشْوِيًّا فَأَكَلَ مِنْهُ ثُمَّ قَامَ إِلَى الصَّلاَةِ وَمَا تَوَضَّأَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ وَالْمُغِيرَةِ وَأَبِي رَافِعٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1829}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Umm Salamah: That she brought a side of roasted meat to the Messenger of Allah (ﷺ), so he ate it from it and stood for Salat, and did not perform Wudu' He said: There are narrations on this topic from 'Abdullah bin Al-Harith, Al-Mughirah, and Abu Rafi' [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib from this route}}
\hadithdefcmd{tirmidhi}{1830}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا شَرِيكٌ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، عَنْ أَبِي جُحَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمَّا أَنَا فَلاَ آكُلُ مُتَّكِئًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَبْدِ اللَّهِ بْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَلِيِّ بْنِ الأَقْمَرِ ‏.‏ وَرَوَى زَكَرِيَّا بْنُ أَبِي زَائِدَةَ وَسُفْيَانُ الثَّوْرِيُّ وَغَيْرُ وَاحِدٍ عَنْ عَلِيِّ بْنِ الأَقْمَرِ هَذَا الْحَدِيثَ وَرَوَى شُعْبَةُ عَنْ سُفْيَانَ الثَّوْرِيِّ هَذَا الْحَدِيثَ عَنْ عَلِيِّ بْنِ الأَقْمَرِ ‏.‏\hadithno{1830}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Juhaidah: That the Messenger of Allah (ﷺ) said: "As for me, I do not eat while reclining." He said: There are narrations on this topic from 'Ali, 'Abdullah bin 'Amr, and 'Abdullah bin Al-'Abbas. [Abu 'Eisa said:] This Hadith is Hasan Sahih, we do not know of it except as a narration of 'Ali bin Al-Aqmar. Zakariyya bin Abi Za'idah, Sufyan bin Sa'eed, and other reported this Hadith from 'Ali bin Al-Aqmar. And Shu'bah reported this Hadith from Sufyan Ath-Thawri from 'Ali bin Al-Aqmar}}
\hadithdefcmd{tirmidhi}{1831}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، وَأَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، قَالُوا حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُحِبُّ الْحَلْوَاءَ وَالْعَسَلَ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَاهُ عَلِيُّ بْنُ مُسْهِرٍ عَنْ هِشَامِ بْنِ عُرْوَةَ وَفِي الْحَدِيثِ كَلاَمٌ أَكْثَرُ مِنْ هَذَا ‏.‏\hadithno{1831}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah: "The Prophet (ﷺ) liked sweets and honey." This Hadith is Hasan Sahih Gharib. 'Ali bin Mus-hir reported it from Hisham bin 'Urwah, and there is more stated in the Hadith than this}}
\hadithdefcmd{tirmidhi}{1832}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ عَلِيٍّ الْمُقَدَّمِيُّ، حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا مُحَمَّدُ بْنُ فَضَاءٍ، حَدَّثَنِي أَبِي، عَنْ عَلْقَمَةَ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا اشْتَرَى أَحَدُكُمْ لَحْمًا فَلْيُكْثِرْ مَرَقَتَهُ فَإِنْ لَمْ يَجِدْ لَحْمًا أَصَابَ مَرَقَةً وَهُوَ أَحَدُ اللَّحْمَيْنِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي ذَرٍّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ مُحَمَّدِ بْنِ فَضَاءٍ ‏.‏ وَمُحَمَّدُ بْنُ فَضَاءٍ هُوَ الْمُعَبِّرُ وَقَدْ تَكَلَّمَ فِيهِ سُلَيْمَانُ بْنُ حَرْبٍ وَعَلْقَمَةُ بْنُ عَبْدِ اللَّهِ هُوَ أَخُو بَكْرِ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ ‏.‏\hadithno{1832}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Alqamah bin Al-Muzani: From his father, who said that the Prophet (ﷺ) said: "When one of you buys meat, then let him increase its broth. For, if he does not find any meat you'll have broth; and it is one of the two meats." And there are narrations on this topic from Abu Dharr. [Abu 'Eisa said:] This Hadith is Gharib, we do not know of it except through this route, as a narration of Muhammad bin Fada', who is Muhammad bin Fada' Al-Mu'abbar, and he has been criticized by Sulaiman bin Harb. 'Alqamah bin 'Abdullah is the brother of Bakr bin 'Abdullah Al-Muzani}}
\hadithdefcmd{tirmidhi}{1833}{حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيِّ بْنِ الأَسْوَدِ الْبَغْدَادِيُّ، حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ الْعَنْقَزِيُّ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ صَالِحِ بْنِ رُسْتُمَ أَبِي عَامِرٍ الْخَزَّازِ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحْقِرَنَّ أَحَدُكُمْ شَيْئًا مِنَ الْمَعْرُوفِ وَإِنْ لَمْ يَجِدْ فَلْيَلْقَ أَخَاهُ بِوَجْهٍ طَلِيقٍ وَإِنِ اشْتَرَيْتَ لَحْمًا أَوْ طَبَخْتَ قِدْرًا فَأَكْثِرْ مَرَقَتَهُ وَاغْرِفْ لِجَارِكَ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رَوَاهُ شُعْبَةُ عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ ‏.‏\hadithno{1833}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Dharr: That the Messenger of Allah (ﷺ) said: "Let one of you not consider any good to be insignificant. If he has nothing, then let him meet his brother with a smiling face. If you buy some meat or cook something in a pot, then increase its broth, and serve some of it to your neighbor." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Shu'bah reported it from Abu 'Imran Al-Jawni}}
\hadithdefcmd{tirmidhi}{1834}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ مُرَّةَ الْهَمْدَانِيِّ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كَمُلَ مِنَ الرِّجَالِ كَثِيرٌ وَلَمْ يَكْمُلْ مِنَ النِّسَاءِ إِلاَّ مَرْيَمُ ابْنَةُ عِمْرَانَ وَآسِيَةُ امْرَأَةُ فِرْعَوْنَ وَفَضْلُ عَائِشَةَ عَلَى النِّسَاءِ كَفَضْلِ الثَّرِيدِ عَلَى سَائِرِ الطَّعَامِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1834}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Musa: That the Prophet (ﷺ) said: "Many a man achieved perfection, but no woman achieved perfection except for Mariam the daughter of 'Imran, and Asiyah the wife of Fir'awn. And the superiority of 'Aishah over other women is like the superiority of Tharid over other foods." He said: There is something on this topic from 'Aishah and Anas. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1835}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْكَرِيمِ أَبِي أُمَيَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، قَالَ زَوَّجَنِي أَبِي فَدَعَا أُنَاسًا فِيهِمْ صَفْوَانُ بْنُ أُمَيَّةَ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ انْهَسُوا اللَّحْمَ نَهْسًا فَإِنَّهُ أَهْنَأُ وَأَمْرَأُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ الْكَرِيمِ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْعِلْمِ فِي عَبْدِ الْكَرِيمِ الْمُعَلِّمِ مِنْهُمْ أَيُّوبُ السَّخْتِيَانِيُّ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{1835}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdullah bin Al-Harith: "My father had me married so he invited people, and Safwan bin Umayyah was among them. So he said: 'Indeed the Messenger of Allah (ﷺ) said: 'Bite the meat (with your teeth) for indeed it is more enjoyable and more wholesome. He said: There are narration on this topic from 'Aishah and Abu Hurairah. [Abu 'Eisa said:] We do not know of this Hadith except through the narration of 'Abdul-Karim. Some of the people of knowledge have criticized 'Abdul-Karim Al-Mu'allim because of his memory, Ayyub As-Sakhtiyani was among them}}
\hadithdefcmd{tirmidhi}{1836}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ أُمَيَّةَ الضَّمْرِيِّ، عَنْ أَبِيهِ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم احْتَزَّ مِنْ كَتِفِ شَاةٍ فَأَكَلَ مِنْهَا ثُمَّ مَضَى إِلَى الصَّلاَةِ وَلَمْ يَتَوَضَّأْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ ‏.‏\hadithno{1836}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ja'far bin 'Amr bin Umayyah Ad-Damri: From his father who said that he saw the Prophet (ﷺ) making incisions (with a knife) into a piece of a lamb shoulder which he ate from, then he went to perform Salat without performing Wudu'. [Abu 'Eisa said:] This Hadith is Hasan Sahih and there is something on this topic from Al-Mughirah bin Shu'bah}}
\hadithdefcmd{tirmidhi}{1837}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِي حَيَّانَ التَّيْمِيِّ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِلَحْمٍ فَرُفِعَ إِلَيْهِ الذِّرَاعُ وَكَانَتْ تُعْجِبُهُ فَنَهَسَ مِنْهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَعَائِشَةَ وَعَبْدِ اللَّهِ بْنِ جَعْفَرٍ وَأَبِي عُبَيْدَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو حَيَّانَ اسْمُهُ يَحْيَى بْنُ سَعِيدِ بْنِ حَيَّانَ وَأَبُو زُرْعَةَ بْنُ عَمْرِو بْنِ جَرِيرٍ اسْمُهُ هَرِمٌ ‏.‏\hadithno{1837}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah: "Some meat was brought to the Prophet (ﷺ) and a foreleg was presented to him, and he used to like it, so he bit from it." He said: There are narrations on this topic from Ibn Mas'ud, 'Aishah, 'Abdullah bin Ja'far, and Abu 'Ubaidah. [Abu 'Eisa said:] This Hadith is Hasan Sahih. Abu Hayyan's (a narrator in the chain) name is Yahya bin Sa'eed bin Hayyan At-Taimi. Abu Zur'ah bin 'Amr bin Jarir's name is Harim}}
\hadithdefcmd{tirmidhi}{1838}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، حَدَّثَنَا يَحْيَى بْنُ عَبَّادٍ أَبُو عَبَّادٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ عَبْدِ الْوَهَّابِ بْنِ يَحْيَى، مِنْ وَلَدِ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ مَا كَانَ الذِّرَاعُ أَحَبَّ اللَّحْمِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَكِنْ كَانَ لاَ يَجِدُ اللَّحْمَ إِلاَّ غِبًّا فَكَانَ يُعَجَّلُ إِلَيْهِ لأَنَّهُ أَعْجَلُهَا نُضْجًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1838}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Aishah: "The foreleg was not the part of the meat that the Messenger of Allah (ﷺ) liked most, but he would not get meat but occasionally. So it would be hastened to him because it cooks quickly." [Abu 'Eisa said:] This Hadith is Hasan Gharib, we do not know of it except from this route}}
\hadithdefcmd{tirmidhi}{1839}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، حَدَّثَنَا مُبَارَكُ بْنُ سَعِيدٍ، هُوَ أَخُو سُفْيَانَ بْنِ سَعِيدٍ الثَّوْرِيِّ عَنْ سُفْيَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ نِعْمَ الإِدَامُ الْخَلُّ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأُمِّ هَانِئٍ ‏.‏\hadithno{1839}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir: That the Prophet (ﷺ) said: "What an excellent condiment vinegar is}}
\hadithdefcmd{tirmidhi}{1840}{حَدَّثَنَا مُحَمَّدُ بْنُ سَهْلِ بْنِ عَسْكَرٍ الْبَغْدَادِيُّ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ نِعْمَ الإِدَامُ الْخَلُّ ‏"‏ ‏.‏ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا يَحْيَى بْنُ حَسَّانَ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ إِلاَّ أَنَّهُ قَالَ ‏"‏ نِعْمَ الإِدَامُ أَوِ الأُدْمُ الْخَلُّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ لاَ نَعْرِفُهُ مِنْ حَدِيثِ هِشَامِ بْنِ عُرْوَةَ إِلاَّ مِنْ حَدِيثِ سُلَيْمَانَ بْنِ بِلاَلٍ ‏.‏\hadithno{1840}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Aishah: That the Messenger of Allah (ﷺ) said: "What an excellent condiment vinegar is." Another chain with similar except that he (ﷺ) said: "What an excellent condiment, or, (the most excellent of) condiments is vinegar." [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib from this route. It is not known as a Hadith of Hisham bin 'Urwah except through the narration of Sulaiman bin Bilal}}
\hadithdefcmd{tirmidhi}{1841}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي حَمْزَةَ الثُّمَالِيِّ، عَنِ الشَّعْبِيِّ، عَنْ أُمِّ هَانِئٍ بِنْتِ أَبِي طَالِبٍ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ هَلْ عِنْدَكُمْ شَيْءٌ ‏"‏ ‏.‏ فَقُلْتُ لاَ إِلاَّ كِسَرٌ يَابِسَةٌ وَخَلٌّ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قَرِّبِيهِ فَمَا أَقْفَرَ بَيْتٌ مِنْ أُدْمٍ فِيهِ خَلٌّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ لاَ نَعْرِفُهُ مِنْ حَدِيثِ أُمِّ هَانِئٍ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو حَمْزَةَ الثُّمَالِيُّ اسْمُهُ ثَابِتُ بْنُ أَبِي صَفِيَّةَ وَأُمُّ هَانِئٍ مَاتَتْ بَعْدَ عَلِيِّ بْنِ أَبِي طَالِبٍ بِزَمَانٍ ‏.‏ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَقَالَ لاَ أَعْرِفُ لِلشَّعْبِيِّ سَمَاعًا مِنْ أُمِّ هَانِئٍ ‏.‏ فَقُلْتُ أَبُو حَمْزَةَ كَيْفَ هُوَ عِنْدَكَ فَقَالَ أَحْمَدُ بْنُ حَنْبَلٍ تَكَلَّمَ فِيهِ وَهُوَ عِنْدِي مُقَارِبُ الْحَدِيثِ ‏.‏\hadithno{1841}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Hani' bint Abi Talib: "The Messenger of Allah (ﷺ) entered upon me and said: 'Do you have anything?' I said: 'No, except a piece of hard bread and vinegar.' so he said: 'Bring it, for a house that has vinegar is not impoverished of condiments." [Abu 'Eisa said:] This Hadith is Hasan Gharib from this route. We do not know of it as a Hadith of Umm Hani' except through this route. Abu Hamzah Ath-Thumali's (a narrator in the chain) name is Thabit bin Abi Safiyyah. And Umm Hani' died some time after 'Ali bin Abi Talib. I asked Muhammad about this Hadith. He said: "I do not know Ash-Sha'bi hearing from Umm Hani'." So I said: "How is Abu Hamzah according to you?" He said: "Ahmad bin Hanbal criticized him, but he is Muqarib (average) in Hadith to me}}
\hadithdefcmd{tirmidhi}{1842}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ الْبَصْرِيُّ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ سُفْيَانَ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ نِعْمَ الإِدَامُ الْخَلُّ ‏"‏ ‏.‏ هَذَا أَصَحُّ مِنْ حَدِيثِ مُبَارَكِ بْنِ سَعِيدٍ ‏.‏\hadithno{1842}\hadithgrade{Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir: That the Prophet (ﷺ) said: "What an excellent condiment vinegar is." There are narrations on this topic from 'Aishah and Umm Hani', and this is more correct than the narration of Mubarak bin Sa'eed (no)}}
\hadithdefcmd{tirmidhi}{1843}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ سُفْيَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَأْكُلُ الْبِطِّيخَ بِالرُّطَبِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَاهُ بَعْضُهُمْ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلٌ وَلَمْ يَذْكُرْ فِيهِ عَنْ عَائِشَةَ وَقَدْ رَوَى يَزِيدُ بْنُ رُومَانَ عَنْ عُرْوَةَ عَنْ عَائِشَةَ هَذَا الْحَدِيثَ ‏.‏\hadithno{1843}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah: "The Prophet (ﷺ) would eat melon with fresh dates." He said: There is something on about this from Anas. [Abu 'Eisa said:] This Hadith is Hasan Gharib. Some of them reported it form Hisham bin 'Urwah from his father in Mursal form from the Prophet (ﷺ), without mentioning "from 'Aishah" in it, And Yazid bin Ruman reported this Hadith from 'Urwah, from 'Aishah}}
\hadithdefcmd{tirmidhi}{1844}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى الْفَزَارِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَأْكُلُ الْقِثَّاءَ بِالرُّطَبِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ إِبْرَاهِيمَ بْنِ سَعْدٍ ‏.‏\hadithno{1844}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah bin Ja'far: "The Messenger of Allah (ﷺ) would eat snake cucumber with fresh dates. [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib, we do not know of it except as a narration of Ibrahim bin Sa'd}}
\hadithdefcmd{tirmidhi}{1845}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَخْبَرَنَا حُمَيْدٌ، وَثَابِتٌ، وَقَتَادَةُ، عَنْ أَنَسٍ، أَنَّ نَاسًا، مِنْ عُرَيْنَةَ قَدِمُوا الْمَدِينَةَ فَاجْتَوَوْهَا فَبَعَثَهُمُ النَّبِيُّ صلى الله عليه وسلم فِي إِبِلِ الصَّدَقَةِ وَقَالَ ‏ "‏ اشْرَبُوا مِنْ أَبْوَالِهَا وَأَلْبَانِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ أَنَسٍ رَوَاهُ أَبُو قِلاَبَةَ عَنْ أَنَسٍ وَرَوَاهُ سَعِيدُ بْنُ أَبِي عَرُوبَةَ عَنْ قَتَادَةَ عَنْ أَنَسٍ ‏.‏\hadithno{1845}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas: "Some of people from 'Urainah arrived in Al-Madinah, and they were uncomfortable (with the climate). So the Messenger of Allah (ﷺ) sent them some camels from charity. He told them: "Drink from their milk and urine." [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib as a narration of Thabit. This Hadith has been reported through other routes from Anas. Abu Qilabah reported it from Anas, and Sa'eed bin Abu 'Arubah reported it from Qatadah, from Anas}}
\hadithdefcmd{tirmidhi}{1846}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا قَيْسُ بْنُ الرَّبِيعِ، ح قَالَ وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْكَرِيمِ الْجُرْجَانِيُّ، عَنْ قَيْسِ بْنِ الرَّبِيعِ الْمَعْنَى، وَاحِدٌ، عَنْ أَبِي هَاشِمٍ يَعْنِي الرُّمَّانِيَّ، عَنْ زَاذَانَ، عَنْ سَلْمَانَ، قَالَ قَرَأْتُ فِي التَّوْرَاةِ أَنَّ بَرَكَةَ الطَّعَامِ الْوُضُوءُ بَعْدَهُ فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَأَخْبَرْتُهُ بِمَا قَرَأْتُ فِي التَّوْرَاةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَرَكَةُ الطَّعَامِ الْوُضُوءُ قَبْلَهُ وَالْوُضُوءُ بَعْدَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى لاَ نَعْرِفُ هَذَا الْحَدِيثَ إِلاَّ مِنْ حَدِيثِ قَيْسِ بْنِ الرَّبِيعِ ‏.‏ وَقَيْسُ بْنُ الرَّبِيعِ يُضَعَّفُ فِي الْحَدِيثِ وَأَبُو هَاشِمٍ الرُّمَّانِيُّ اسْمُهُ يَحْيَى بْنُ دِينَارٍ ‏.‏\hadithno{1846}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salman: "I read in the Tawrah that the blessing for food is in the Wudu' after it. So I mentioned that to the Prophet (ﷺ), telling him what I read in the Tawrah. So the Messenger of Allah (ﷺ) said: 'The food's blessing is in the Wudu' before it and the Wudu' after it.'" He said: There are narrations on this topic from Anas and Abu Hurairah. [Abu 'Eisa said:] We do not know of this Hadith except as a narration of Qais bin Ar-Rabi'. Qais [bin Ar-Rabi'] was graded weak in Hadith. Abu Hashim Ar-Rumani's (a narrator in the chain) name is Yahya bin Dinar}}
\hadithdefcmd{tirmidhi}{1847}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ مِنَ الْخَلاَءِ فَقُرِّبَ إِلَيْهِ طَعَامٌ فَقَالُوا أَلاَ نَأْتِيكَ بِوَضُوءٍ قَالَ ‏ "‏ إِنَّمَا أُمِرْتُ بِالْوُضُوءِ إِذَا قُمْتُ إِلَى الصَّلاَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ عَمْرُو بْنُ دِينَارٍ عَنْ سَعِيدِ بْنِ الْحُوَيْرِثِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ وَقَالَ عَلِيُّ بْنُ الْمَدِينِيِّ قَالَ يَحْيَى بْنُ سَعِيدٍ كَانَ سُفْيَانُ الثَّوْرِيُّ يَكْرَهُ غَسْلَ الْيَدِ قَبْلَ الطَّعَامِ وَكَانَ يَكْرَهُ أَنْ يُوضَعَ الرَّغِيفُ تَحْتَ الْقَصْعَةِ ‏\hadithno{1847}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Abbas: "The Messenger of Allah (ﷺ) cae out from the toilet and some food was brought to him. They said: 'Shall we bring you some water for Wudu'?' He said: 'I have only been ordered to perform Wudu' when standing for Salat.'" [Abu 'Eisa said:] This Hadith is Hasan [Sahih]. 'Amr bin Dinar has reported it from Sa'eed bin Al-Huwairith, from Ibn 'Abbas. 'Ali bin Al-Madini said: 'Sufyan Ath-Thawri disliked washing the hands before eating food, and he disliked placing the bread under the bowl}}
\hadithdefcmd{tirmidhi}{1848}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا الْعَلاَءُ بْنُ الْفَضْلِ بْنِ عَبْدِ الْمَلِكِ بْنِ أَبِي سَوِيَّةَ أَبُو الْهُذَيْلِ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عِكْرَاشٍ، عَنْ أَبِيهِ، عِكْرَاشِ بْنِ ذُؤَيْبٍ قَالَ بَعَثَنِي بَنُو مُرَّةَ بْنِ عُبَيْدٍ بِصَدَقَاتِ أَمْوَالِهِمْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَدِمْتُ عَلَيْهِ الْمَدِينَةَ فَوَجَدْتُهُ جَالِسًا بَيْنَ الْمُهَاجِرِينَ وَالأَنْصَارِ قَالَ ثُمَّ أَخَذَ بِيَدِي فَانْطَلَقَ بِي إِلَى بَيْتِ أُمِّ سَلَمَةَ فَقَالَ ‏"‏ هَلْ مِنْ طَعَامٍ ‏"‏ ‏.‏ فَأُتِينَا بِجَفْنَةٍ كَثِيرَةِ الثَّرِيدِ وَالْوَذْرِ وَأَقْبَلْنَا نَأْكُلُ مِنْهَا فَخَبَطْتُ بِيَدِي مِنْ نَوَاحِيهَا وَأَكَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ بَيْنِ يَدَيْهِ فَقَبَضَ بِيَدِهِ الْيُسْرَى عَلَى يَدِي الْيُمْنَى ثُمَّ قَالَ ‏"‏ يَا عِكْرَاشُ كُلْ مِنْ مَوْضِعٍ وَاحِدٍ فَإِنَّهُ طَعَامٌ وَاحِدٌ ‏"‏ ‏.‏ ثُمَّ أُتِينَا بِطَبَقٍ فِيهِ أَلْوَانُ الرُّطَبِ أَوِ التَّمْرِ عُبَيْدُ اللَّهِ شَكَّ قَالَ فَجَعَلْتُ آكُلُ مِنْ بَيْنِ يَدَىَّ وَجَالَتْ يَدُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الطَّبَقِ وَقَالَ ‏"‏ يَا عِكْرَاشُ كُلْ مِنْ حَيْثُ شِئْتَ فَإِنَّهُ غَيْرُ لَوْنٍ وَاحِدٍ ‏"‏ ‏.‏ ثُمَّ أُتِينَا بِمَاءٍ فَغَسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ وَمَسَحَ بِبَلَلِ كَفَّيْهِ وَجْهَهُ وَذِرَاعَيْهِ وَرَأْسَهُ وَقَالَ ‏"‏ يَا عِكْرَاشُ هَذَا الْوُضُوءُ مِمَّا غَيَّرَتِ النَّارُ ‏"‏ ‏.‏ وَفِي الْحَدِيثِ قِصَّةٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الْعَلاَءِ بْنِ الْفَضْلِ وَقَدْ تَفَرَّدَ الْعَلاَءُ بِهَذَا الْحَدِيثِ وَلاَ نَعْرِفُ لِعِكْرَاشٍ عَنِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ هَذَا الْحَدِيثَ ‏.‏\hadithno{1848}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ikrash bin Dhu'aib: "Banu Murrah bin 'Ubaid sent me to bring the Sadaqah from their wealth of the Messenger of Allah (ﷺ). I arrived with him in Al-Madinah and found him sitting between the Muhajirin and the Ansar." He said: "Then he took my hand and brought me to the home of Umm Salamah and he said: 'Do you have any food?' So a bowl containing a lot of Tharid with pieces of meat was brought to us, and presented for us to eat from it. So I began wandering my around it while the Messenger of Allah (ﷺ) ate from what was in front of him. He grabbed my right hand with his left hand, then he said: 'O 'Ikrash! Eat from one spot, for indeed the food is one.' Then a plate containing various dried dates" - or fresh dates - 'Ubaidullah (a narrator) was not sure. He said: "I began eating what was in front of me, while the hand of the Messenger of Allah (ﷺ) roamed about the plate. He said: 'O 'Ikrash! Eat from wherever you like, for indeed it is not all from the same variety.' Then water was brought, so the Messenger of Allah (ﷺ) washed his hands, and with the wetness of his hands he wiped his face, his forearms, and his head, and he said: 'O Ikrash! This is the Wudu' for that which has been altered by fire.'" [Abu 'Eisa said:] This Hadith is Gharib, we do not know of it except through the narration of Al-'Ala' bin Al-Fadl, and Al-Ala'was alone with this narration, and there is more in the story in the Hadith. And we do not know a Hadith from the Prophet (ﷺ) by 'Ikrash except this}}
\hadithdefcmd{tirmidhi}{1849}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ أَبِي طَالُوتَ، قَالَ دَخَلْتُ عَلَى أَنَسِ بْنِ مَالِكٍ وَهُوَ يَأْكُلُ الْقَرْعَ وَهُوَ يَقُولُ يَا لَكِ شَجَرَةً مَا أُحِبُّكِ إِلاَّ لِحُبِّ رَسُولِ اللَّهِ صلى الله عليه وسلم إِيَّاكِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ حَكِيمِ بْنِ جَابِرٍ عَنْ أَبِيهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1849}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Talut: "I entered upon Anas bin Malik while he was eating gourd, and he was saying: 'O you tree! I do not like you but because of the Messenger of Allah (ﷺ) liked you.'" He said: There is something on this topic from Hakim bin Jarir, from his father. [Abu 'Eisa said:] This Hadith is Gharib from this route}}
\hadithdefcmd{tirmidhi}{1850}{حَدَّثَنَا مُحَمَّدُ بْنُ مَيْمُونٍ الْمَكِّيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَتَبَّعُ فِي الصَّحْفَةِ - يَعْنِي الدُّبَّاءَ فَلاَ أَزَالُ أُحِبُّهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ أَنَسٍ وَرُوِيَ أَنَّهُ رَأَى الدُّبَّاءَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ مَا هَذَا قَالَ ‏ "‏ هَذَا الدُّبَّاءُ نُكَثِّرُ بِهِ طَعَامَنَا ‏"‏ ‏.‏\hadithno{1850}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik: "I saw the Messenger of Allah (ﷺ) taking from the sides around the dish - meaning the gourd. Since then I still like it." [Abu 'Eisa said:] This Hadith is Hasan Sahih. This Hadith has been reported through more than one route from Anas bin Malik}}
\hadithdefcmd{tirmidhi}{1851}{\hadithno{1851}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1852}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، وَأَبُو نُعَيْمٍ قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنْ رَجُلٍ، يُقَالُ لَهُ عَطَاءٌ مِنْ أَهْلِ الشَّامِ عَنْ أَبِي أَسِيدٍ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ كُلُوا الزَّيْتَ وَادَّهِنُوا بِهِ فَإِنَّهُ مِنْ شَجَرَةٍ مُبَارَكَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ سُفْيَانَ الثَّوْرِيِّ عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى ‏.‏\hadithno{1852}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Asid: "The Prophet (ﷺ) said: Eat of its oil and use it (the olives), for indeed it is from a blessed tree." [Abu 'Eisa said:] This Hadith is Gharib from this route. We only know of it from the narration of Sufyan At-Thawri, from 'Abdullah bin 'Eisa}}
\hadithdefcmd{tirmidhi}{1853}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، يُخْبِرُهُمْ ذَاكَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَفَى أَحَدَكُمْ خَادِمُهُ طَعَامَهُ حَرَّهُ وَدُخَانَهُ فَلْيَأْخُذْ بِيَدِهِ فَلْيُقْعِدْهُ مَعَهُ فَإِنْ أَبَى فَلْيَأْخُذْ لُقْمَةً فَلْيُطْعِمْهَا إِيَّاهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو خَالِدٍ وَالِدُ إِسْمَاعِيلَ اسْمُهُ سَعْدٌ ‏.‏\hadithno{1853}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Isma'il bin Abi Khalid: From his father that Abu Hurairah informed them that the Prophet (ﷺ) said: "When the servant of one of you has endured heat and smoke preparing his food for him, then let him take him by the hand and make him sit him down with him. If he refuses, then let him take a morsel and feed him with it." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Abu Khalid is the father of Isma'il, his name is Sa'd}}
\hadithdefcmd{tirmidhi}{1854}{حَدَّثَنَا يُوسُفُ بْنُ حَمَّادٍ الْمَعْنِيُّ الْبَصْرِيُّ، حَدَّثَنَا عُثْمَانُ بْنُ عَبْدِ الرَّحْمَنِ الْجُمَحِيُّ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَفْشُوا السَّلاَمَ وَأَطْعِمُوا الطَّعَامَ وَاضْرِبُوا الْهَامَ تُورَثُوا الْجِنَانَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَابْنِ عُمَرَ وَأَنَسٍ وَعَبْدِ اللَّهِ بْنِ سَلاَمٍ وَعَبْدِ الرَّحْمَنِ بْنِ عَائِشٍ وَشُرَيْحِ بْنِ هَانِئٍ عَنْ أَبِيهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ ابْنِ زِيَادٍ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{1854}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah: That the Prophet (ﷺ) said: "Spread the (greetings of) Salam, feed others, strike the heads (of the enemy disbelievers); you will inherit Paradise." He said: There are narrations on this topic from 'Abdullah bin 'Amr, Ibn 'Umar, Anas, 'Abdus-Salam, 'Abdur-Rahman bin 'Aish, and Shuraih bin Hani' from his father. [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib as a narration of [Ibn Ziyad] from Abu Hurairah}}
\hadithdefcmd{tirmidhi}{1855}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اعْبُدُوا الرَّحْمَنَ وَأَطْعِمُوا الطَّعَامَ وَأَفْشُوا السَّلاَمَ تَدْخُلُوا الْجَنَّةَ بِسَلاَمٍ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1855}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Abdullah bin 'Amr: That the Messenger of Allah (ﷺ) said: "(All of you) worship Ar-Rahman, feed others, spread the (greeting of) Salam, then you will enter Paradise in security." He said: This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1856}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا مُحَمَّدُ بْنُ يَعْلَى الْكُوفِيُّ، حَدَّثَنَا عَنْبَسَةُ بْنُ عَبْدِ الرَّحْمَنِ الْقُرَشِيُّ، عَنْ عَبْدِ الْمَلِكِ بْنِ عَلاَّقٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ تَعَشَّوْا وَلَوْ بِكَفٍّ مِنْ حَشَفٍ فَإِنَّ تَرْكَ الْعَشَاءِ مَهْرَمَةٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ مُنْكَرٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَعَنْبَسَةُ يُضَعَّفُ فِي الْحَدِيثِ وَعَبْدُ الْمَلِكِ بْنُ عَلاَّقٍ مَجْهُولٌ ‏.‏\hadithno{1856}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik: That the Messenger of Allah (ﷺ) said: "Take the 'Asha' meal, even if it is just with a handful of something to fill. For indeed avoiding the 'Asha' is from senility." [Abu 'Eisa said:] This Hadith is Munkar, we do not know of it except from this route. 'Anbasah was graded weak is Hadith. 'Abdul-Malik bin 'Allaq is unknown}}
\hadithdefcmd{tirmidhi}{1857}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ الْهَاشِمِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، أَنَّهُ دَخَلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَعِنْدَهُ طَعَامٌ فَقَالَ ‏ "‏ ادْنُ يَا بُنَىَّ وَسَمِّ اللَّهَ وَكُلْ بِيَمِينِكَ وَكُلْ مِمَّا يَلِيكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِي وَجْزَةَ السَّعْدِيِّ عَنْ رَجُلٍ مِنْ مُزَيْنَةَ عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ ‏.‏ وَقَدِ اخْتَلَفَ أَصْحَابُ هِشَامِ بْنِ عُرْوَةَ فِي رِوَايَةِ هَذَا الْحَدِيثِ ‏.‏ وَأَبُو وَجْزَةَ السَّعْدِيُّ اسْمُهُ يَزِيدُ بْنُ عُبَيْدٍ ‏.‏\hadithno{1857}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Umar bin Abi Salamah: That he entered upon the Messenger of Allah (ﷺ) while he has some food. He said: "Sit down O my son! Mention Allah's Name and eat with your right hand, and eat what is nearest to you." [Abu 'Eisa said:] It has been reported from Hisham bin 'Urwah, from Abu Wajzah As-Sa'idi, from a man from Muzainah, from 'Umar bin Abu Salamah. The Companions of Hisham bin 'Urwah differed in reporting this Hadith. Abu Wajzah As-Sa'di's name is Yazid bin 'Ubaid}}
\hadithdefcmd{tirmidhi}{1858}{\hadithno{1858}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1859}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَعْقُوبُ بْنُ الْوَلِيدِ الْمَدَنِيُّ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الشَّيْطَانَ حَسَّاسٌ لَحَّاسٌ فَاحْذَرُوهُ عَلَى أَنْفُسِكُمْ مَنْ بَاتَ وَفِي يَدِهِ رِيحُ غَمَرٍ فَأَصَابَهُ شَيْءٌ فَلاَ يَلُومَنَّ إِلاَّ نَفْسَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ مِنْ حَدِيثِ سُهَيْلِ بْنِ أَبِي صَالِحٍ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1859}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "Indeed Ash-Shaitan has a sense of taste, for which he licks, so beware of him. So whoever spends the night with [a smell] on his hand and something happens to him, then let him not blame anyone but himself." [Abu 'Eisa said:] This Hadith is Gharib from this route. It has also been reported in a narration of Suhail bin Abi Salih, from his father, from Abu Hurairah, from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1860}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ إِسْحَاقَ الْبَغْدَادِيُّ الصَّاغَانِيُّ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ الْمَدَائِنِيُّ، حَدَّثَنَا مَنْصُورُ بْنُ أَبِي الأَسْوَدِ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ بَاتَ وَفِي يَدِهِ رِيحُ غَمَرٍ فَأَصَابَهُ شَيْءٌ فَلاَ يَلُومَنَّ إِلاَّ نَفْسَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ الأَعْمَشِ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1860}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "Whoever spends the night with [a smell] on his hand and something happens to him, then let him not blame anyone but himself." [Abu 'Eisa said:] This Hadith is Hasan Gharib, we do not know of it as a narration of Al-'Amash except through this route}}
